@@ -381,9 +381,14 @@ class Client:
                 "Failed to upload, unknown cause", e)
 
         if not file_data or not file_data.get("uploadFile", None):
+            try:
+                errors = response.json().get("errors", [])
+                error_msg = next(iter(errors), {}).get("message",
+                                                       "Unknown error")
+            except Exception as e:
+                error_msg = "Unknown error"
             raise labelbox.exceptions.LabelboxError(
-                "Failed to upload, message: %s" % file_data or
-                file_data.get("error"))
+                "Failed to upload, message: %s" % error_msg)
 
         return file_data["uploadFile"]["url"]
 
