@@ -2,6 +2,7 @@ import logging
 from concurrent.futures import ThreadPoolExecutor, as_completed
 from typing import Callable, Generator, Iterable, Union, Optional
 from uuid import uuid4
+import warnings
 
 from tqdm import tqdm
 
@@ -34,13 +35,17 @@ class LabelList:
             self, ontology_builder: "ontology.OntologyBuilder") -> "LabelList":
         """
         Adds schema ids to all FeatureSchema objects in the Labels.
-        This is necessary for MAL.
 
         Args:
             ontology_builder: The ontology that matches the feature names assigned to objects in this LabelList
         Returns:
             LabelList. useful for chaining these modifying functions
+
+        Note: You can now import annotations using names directly without having to lookup schema_ids  
         """
+        warnings.warn("This method is deprecated and will be "
+                      "removed in a future release. Feature schema ids"
+                      " are no longer required for importing.")
         for label in self._data:
             label.assign_feature_schema_ids(ontology_builder)
         return self
@@ -192,6 +197,9 @@ class LabelGenerator(PrefetchGenerator):
             label.assign_feature_schema_ids(ontology_builder)
             return label
 
+        warnings.warn("This method is deprecated and will be "
+                      "removed in a future release. Feature schema ids"
+                      " are no longer required for importing.")
         self._fns['assign_feature_schema_ids'] = _assign_ids
         return self
 
