@@ -15,12 +15,16 @@ from labelbox import utils
 from labelbox.exceptions import InvalidQueryError, LabelboxError, ResourceNotFoundError, InvalidAttributeError
 from labelbox.orm.db_object import DbObject, Updateable, Deletable
 from labelbox.orm.model import Entity, Field, Relationship
+from labelbox.exceptions import MalformedQueryException
 
 if TYPE_CHECKING:
     from labelbox import Task, User, DataRow
 
 logger = logging.getLogger(__name__)
 
+MAX_DATAROW_PER_API_OPERATION = 150000
+MAX_DATAROW_WITH_METADATA = 30000
+
 
 class Dataset(DbObject, Updateable, Deletable):
     """ A Dataset is a collection of DataRows.
@@ -226,6 +230,7 @@ class Dataset(DbObject, Updateable, Deletable):
         >>>     {DataRow.row_data:"/path/to/file1.jpg"},
         >>>     "path/to/file2.jpg",
         >>>     {"tileLayerUrl" : "http://", ...}
+        >>>     {"conversationalData" : [...], ...}
         >>>     ])
 
         For an example showing how to upload tiled data_rows see the following notebook:
@@ -254,12 +259,11 @@ class Dataset(DbObject, Updateable, Deletable):
         def upload_if_necessary(item):
             row_data = item['row_data']
             if os.path.exists(row_data):
-                item_url = self.client.upload_file(item['row_data'])
-                item = {
-                    "row_data": item_url,
-                    "external_id": item.get('external_id', item['row_data']),
-                    "attachments": item.get('attachments', [])
-                }
+                item_url = self.client.upload_file(row_data)
+                item['row_data'] = item_url
+                if 'external_id' not in item:
+                    # Default `external_id` to local file name
+                    item['external_id'] = row_data
             return item
 
         def validate_attachments(item):
@@ -280,6 +284,33 @@ class Dataset(DbObject, Updateable, Deletable):
                     )
             return attachments
 
+        def validate_conversational_data(conversational_data: list) -> None:
+            """
+            Checks each conversational message for keys expected as per https://docs.labelbox.com/reference/text-conversational#sample-conversational-json
+
+            Args:
+                conversational_data (list): list of dictionaries.
+            """
+
+            def check_message_keys(message):
+                accepted_message_keys = set([
+                    "messageId", "timestampUsec", "content", "user", "align",
+                    "canLabel"
+                ])
+                for key in message.keys():
+                    if not key in accepted_message_keys:
+                        raise KeyError(
+                            f"Invalid {key} key found! Accepted keys in messages list is {accepted_message_keys}"
+                        )
+
+            if conversational_data and not isinstance(conversational_data,
+                                                      list):
+                raise ValueError(
+                    f"conversationalData must be a list. Found {type(conversational_data)}"
+                )
+
+            [check_message_keys(message) for message in conversational_data]
+
         def parse_metadata_fields(item):
             metadata_fields = item.get('metadata_fields')
             if metadata_fields:
@@ -321,6 +352,27 @@ class Dataset(DbObject, Updateable, Deletable):
             if "tileLayerUrl" in item:
                 validate_attachments(item)
                 return item
+
+            if "conversationalData" in item:
+                messages = item.pop("conversationalData")
+                version = item.pop("version")
+                type = item.pop("type")
+                if "externalId" in item:
+                    external_id = item.pop("externalId")
+                    item["external_id"] = external_id
+                validate_conversational_data(messages)
+                one_conversation = \
+                    {
+                        "type": type,
+                        "version": version,
+                        "messages": messages
+                    }
+                conversationUrl = self.client.upload_data(
+                    json.dumps(one_conversation),
+                    content_type="application/json",
+                    filename="conversational_data.json")
+                item["row_data"] = conversationUrl
+
             # Convert all payload variations into the same dict format
             item = format_row(item)
             # Make sure required keys exist (and there are no extra keys)
@@ -342,14 +394,18 @@ class Dataset(DbObject, Updateable, Deletable):
                 f"Must pass an iterable to create_data_rows. Found {type(items)}"
             )
 
+        if len(items) > MAX_DATAROW_PER_API_OPERATION:
+            raise MalformedQueryException(
+                f"Cannot create more than {MAX_DATAROW_PER_API_OPERATION} DataRows per function call."
+            )
+
         # TODO: If any datarows contain metadata, we're limiting max # of datarows
         # until we address performance issues with datarow create with metadata
-        max_datarow_with_metadata = 30_000
-        if (len(items) > max_datarow_with_metadata):
+        if len(items) > MAX_DATAROW_WITH_METADATA:
             for row in items:
                 if 'metadata_fields' in row:
-                    raise ValueError(
-                        f"Cannot create more than {max_datarow_with_metadata} DataRows, if any DataRows contain metadata"
+                    raise MalformedQueryException(
+                        f"Cannot create more than {MAX_DATAROW_WITH_METADATA} DataRows, if any DataRows contain metadata"
                     )
 
         with ThreadPoolExecutor(file_upload_thread_count) as executor:
@@ -413,7 +469,9 @@ class Dataset(DbObject, Updateable, Deletable):
                 external_id)
         return data_rows[0]
 
-    def export_data_rows(self, timeout_seconds=120) -> Generator:
+    def export_data_rows(self,
+                         timeout_seconds=120,
+                         include_metadata: bool = False) -> Generator:
         """ Returns a generator that produces all data rows that are currently
         attached to this dataset.
 
@@ -422,29 +480,31 @@ class Dataset(DbObject, Updateable, Deletable):
 
         Args:
             timeout_seconds (float): Max waiting time, in seconds.
+            include_metadata (bool): True to return related DataRow metadata
         Returns:
             Generator that yields DataRow objects belonging to this dataset.
         Raises:
             LabelboxError: if the export fails or is unable to download within the specified time.
         """
         id_param = "datasetId"
-        query_str = """mutation GetDatasetDataRowsExportUrlPyApi($%s: ID!)
-            {exportDatasetDataRows(data:{datasetId: $%s }) {downloadUrl createdAt status}}
-        """ % (id_param, id_param)
+        metadata_param = "includeMetadataInput"
+        query_str = """mutation GetDatasetDataRowsExportUrlPyApi($%s: ID!, $%s: Boolean!)
+            {exportDatasetDataRows(data:{datasetId: $%s , includeMetadataInput: $%s}) {downloadUrl createdAt status}}
+        """ % (id_param, metadata_param, id_param, metadata_param)
         sleep_time = 2
         while True:
-            res = self.client.execute(query_str, {id_param: self.uid})
+            res = self.client.execute(query_str, {
+                id_param: self.uid,
+                metadata_param: include_metadata
+            })
             res = res["exportDatasetDataRows"]
             if res["status"] == "COMPLETE":
                 download_url = res["downloadUrl"]
                 response = requests.get(download_url)
                 response.raise_for_status()
                 reader = ndjson.reader(StringIO(response.text))
-                # TODO: Update result to parse metadataFields when resolver returns
-                return (Entity.DataRow(self.client, {
-                    **result, 'metadataFields': [],
-                    'customMetadata': []
-                }) for result in reader)
+                return (
+                    Entity.DataRow(self.client, result) for result in reader)
             elif res["status"] == "FAILED":
                 raise LabelboxError("Data row export failed.")
 
